"""
Auto-generated gmb_place_actions resource.

DO NOT EDIT THIS FILE MANUALLY.
Run `python scripts/generate_resources.py` to regenerate.
"""

from __future__ import annotations

from typing import TYPE_CHECKING, Any

if TYPE_CHECKING:
    from ..client.base import BaseClient


class GmbPlaceActionsResource:
    """
    gmb_place_actions operations.
    """

    def __init__(self, client: BaseClient) -> None:
        self._client = client

    def _build_params(self, **kwargs: Any) -> dict[str, Any]:
        """Build query parameters, filtering None values."""

        def to_camel(s: str) -> str:
            parts = s.split("_")
            return parts[0] + "".join(p.title() for p in parts[1:])

        return {to_camel(k): v for k, v in kwargs.items() if v is not None}

    def _build_payload(self, **kwargs: Any) -> dict[str, Any]:
        """Build request payload, filtering None values."""
        from datetime import datetime

        def to_camel(s: str) -> str:
            parts = s.split("_")
            return parts[0] + "".join(p.title() for p in parts[1:])

        result: dict[str, Any] = {}
        for k, v in kwargs.items():
            if v is None:
                continue
            if isinstance(v, datetime):
                result[to_camel(k)] = v.isoformat()
            else:
                result[to_camel(k)] = v
        return result

    def list_google_business_place_actions(
        self,
        account_id: str,
        *,
        page_size: int | None = 100,
        page_token: str | None = None,
    ) -> dict[str, Any]:
        """List place action links (booking, ordering, reservations)"""
        params = self._build_params(
            page_size=page_size,
            page_token=page_token,
        )
        return self._client._get(
            f"/v1/accounts/{account_id}/gmb-place-actions", params=params
        )

    def create_google_business_place_action(
        self, account_id: str, uri: str, place_action_type: str
    ) -> dict[str, Any]:
        """Create a place action link (booking, ordering, reservation)"""
        payload = self._build_payload(
            uri=uri,
            place_action_type=place_action_type,
        )
        return self._client._post(
            f"/v1/accounts/{account_id}/gmb-place-actions", data=payload
        )

    def delete_google_business_place_action(
        self, account_id: str, name: str
    ) -> dict[str, Any]:
        """Delete a place action link"""
        params = self._build_params(
            name=name,
        )
        return self._client._delete(
            f"/v1/accounts/{account_id}/gmb-place-actions", params=params
        )

    async def alist_google_business_place_actions(
        self,
        account_id: str,
        *,
        page_size: int | None = 100,
        page_token: str | None = None,
    ) -> dict[str, Any]:
        """List place action links (booking, ordering, reservations) (async)"""
        params = self._build_params(
            page_size=page_size,
            page_token=page_token,
        )
        return await self._client._aget(
            f"/v1/accounts/{account_id}/gmb-place-actions", params=params
        )

    async def acreate_google_business_place_action(
        self, account_id: str, uri: str, place_action_type: str
    ) -> dict[str, Any]:
        """Create a place action link (booking, ordering, reservation) (async)"""
        payload = self._build_payload(
            uri=uri,
            place_action_type=place_action_type,
        )
        return await self._client._apost(
            f"/v1/accounts/{account_id}/gmb-place-actions", data=payload
        )

    async def adelete_google_business_place_action(
        self, account_id: str, name: str
    ) -> dict[str, Any]:
        """Delete a place action link (async)"""
        params = self._build_params(
            name=name,
        )
        return await self._client._adelete(
            f"/v1/accounts/{account_id}/gmb-place-actions", params=params
        )
